@@ -61,21 +61,32 @@ import com.openexchange.session.Session;
  */
 public interface DriveSubscriptionStore {
 
+    /**
+     * Adds one ore more subscriptions for the device identified by the supplied token to the specified root folder IDs. Any previous
+     * registrations of the device in the same context using the same service ID / root folder ID combination are replaced implicitly.
+     *
+     * @param session The session
+     * @param serviceID The service ID
+     * @param token The device's registration token
+     * @param rootFolderIDs The root folder IDs
+     * @return The subscriptions
+     */
+    List<Subscription> subscribe(Session session, String serviceID, String token, List<String> rootFolderIDs) throws OXException;
+
     /**
      * Adds a subscription for the device identified by the supplied token to the specified root folder ID. Any previous registrations
-     * of the device in the same context using the same service ID combination are removed implicitly.
+     * of the device in the same context using the same service ID / root folder ID combination are replaced implicitly.
      *
      * @param session The session
      * @param serviceID The service ID
      * @param token The device's registration token
      * @param rootFolderID The root folder ID
-     * @return The new subscription
-     * @throws OXException
+     * @return The subscription
      */
     Subscription subscribe(Session session, String serviceID, String token, String rootFolderID) throws OXException;
 
     /**
-     * Removes the subscription of the device with the given registration token.
+     * Removes all subscriptions of the device with the given registration token.
      *
      * @param session The session
      * @param serviceID The service ID
@@ -84,6 +95,17 @@ public interface DriveSubscriptionStore {
      */
     boolean unsubscribe(Session session, String serviceID, String token) throws OXException;
 
+    /**
+     * Removes subscriptions for specific root folder IDs of the device with the given registration token.
+     *
+     * @param session The session
+     * @param serviceID The service ID
+     * @param token The device's registration token
+     * @param rootFolderIDs The root folder IDs, or <code>null</code> to remove the subscriptions for all root folders
+     * @return <code>true</code> if a subscription was removed, <code>false</code>, otherwise
+     */
+    boolean unsubscribe(Session session, String serviceID, String token, List<String> rootFolderIDs) throws OXException;
+
     /**
      * Updates the registration ID for a device.
      *
