@@ -78,11 +78,11 @@ public class DriveEventSubscriptionsCreateTableTask extends UpdateTaskAdapter {
     @Override
     public void perform(final PerformParameters params) throws OXException {
         Connection writeCon = params.getConnection();
-        boolean rollback = false;
+        int rollback = 0;
         PreparedStatement stmt = null;
         try {
             writeCon.setAutoCommit(false); // BEGIN
-            rollback = true;
+            rollback = 1;
             final String[] tableNames = DriveEventSubscriptionsCreateTableService.getTablesToCreate();
             final String[] createStmts = DriveEventSubscriptionsCreateTableService.getCreateStmts();
             for (int i = 0; i < tableNames.length; i++) {
@@ -97,17 +97,19 @@ public class DriveEventSubscriptionsCreateTableTask extends UpdateTaskAdapter {
                 }
             }
             writeCon.commit(); // COMMIT
-            rollback = false;
+            rollback = 2;
         } catch (final OXException e) {
             throw e;
         } catch (final Exception e) {
             throw DriveExceptionCodes.DB_ERROR.create(e, e.getMessage());
         } finally {
             closeSQLStuff(stmt);
-            if (rollback) {
-                Databases.rollback(writeCon);
+            if (rollback > 0) {
+                if (rollback==1) {
+                    Databases.rollback(writeCon);
+                }
+                Databases.autocommit(writeCon);
             }
-            Databases.autocommit(writeCon);
         }
     }
 
