@@ -177,67 +177,72 @@ public class DriveEventServiceImpl implements org.osgi.service.event.EventHandle
 
     @Override
     public void handleEvent(final Event event) {
-        LOG.trace("{}", new Object() { @Override public String toString() { return FileStorageEventHelper.createDebugMessage("event", event);}});
-        /*
-         * check event
-         */
-        if (false == check(event)) {
-            LOG.debug("Unable to handle incomplete event: {}", event);
-            return;
-        }
-        String fileName = (String) event.getProperty(FILE_NAME);
-        if (Strings.isNotEmpty(fileName) && (driveUtility.isInvalidFileName(fileName) || driveUtility.isIgnoredFileName(fileName))) {
-            LOG.trace("Skipping event processing for ignored file: {}", fileName);
-            return;
-        }
-        /*
-         * create task to insert affected folders into buffer
-         */
-        AbstractTask<Void> insertTask = new AbstractTask<Void>() {
-
-            @Override
-            public Void call() throws Exception {
-                /*
-                 * extract properties
-                 */
-                Session session = (Session)event.getProperty(SESSION);
-                Integer contextID = Integer.valueOf(session.getContextId());
-                String folderID = (String)(event.containsProperty(PARENT_FOLDER_ID) ?
-                    event.getProperty(PARENT_FOLDER_ID) : event.getProperty(FOLDER_ID));
-                String oldParentFolderID = (String)event.getProperty(OLD_PARENT_FOLDER_ID);
-                String[] folderPath = (String[])event.getProperty(FOLDER_PATH);
-                /*
-                 * get buffer for this context
-                 */
-                FolderBuffer buffer = folderBuffers.get(contextID);
-                if (null == buffer) {
-                    buffer = new FolderBuffer(contextID.intValue(), consolidationTime, maxDelayTime, defaultDelayTime);
-                    FolderBuffer existingBuffer = folderBuffers.putIfAbsent(contextID, buffer);
-                    if (null != existingBuffer) {
-                        buffer = existingBuffer;
-                    }
-                }
-                /*
-                 * add to buffer
-                 */
-                if (null != folderPath) {
-                    buffer.add(session, folderID, Arrays.asList(folderPath));
-                } else {
-                    buffer.add(session, folderID);
-                }
-                if (null != oldParentFolderID) {
-                    buffer.add(session, oldParentFolderID);
-                }
-                return null;
-            }
-        };
-        /*
-         * add event to buffer asynchronously if possible
-         */
         try {
+            LOG.trace("{}", new Object() {
+
+                @Override
+                public String toString() {
+                    return FileStorageEventHelper.createDebugMessage("event", event);
+                }
+            });
+            /*
+             * check event
+             */
+            if (false == check(event)) {
+                LOG.debug("Unable to handle incomplete event: {}", event);
+                return;
+            }
+            Session session = (Session) event.getProperty(SESSION);
+            String fileName = (String) event.getProperty(FILE_NAME);
+            if (Strings.isNotEmpty(fileName) && (driveUtility.isInvalidFileName(fileName) || driveUtility.isIgnoredFileName(fileName, session))) {
+                LOG.trace("Skipping event processing for ignored file: {}", fileName);
+                return;
+            }
+            /*
+             * create task to insert affected folders into buffer
+             */
+            AbstractTask<Void> insertTask = new AbstractTask<Void>() {
+
+                @Override
+                public Void call() throws Exception {
+                    /*
+                     * extract properties
+                     */
+                    Integer contextID = Integer.valueOf(session.getContextId());
+                    String folderID = (String) (event.containsProperty(PARENT_FOLDER_ID) ? event.getProperty(PARENT_FOLDER_ID) : event.getProperty(FOLDER_ID));
+                    String oldParentFolderID = (String) event.getProperty(OLD_PARENT_FOLDER_ID);
+                    String[] folderPath = (String[]) event.getProperty(FOLDER_PATH);
+                    /*
+                     * get buffer for this context
+                     */
+                    FolderBuffer buffer = folderBuffers.get(contextID);
+                    if (null == buffer) {
+                        buffer = new FolderBuffer(contextID.intValue(), consolidationTime, maxDelayTime, defaultDelayTime);
+                        FolderBuffer existingBuffer = folderBuffers.putIfAbsent(contextID, buffer);
+                        if (null != existingBuffer) {
+                            buffer = existingBuffer;
+                        }
+                    }
+                    /*
+                     * add to buffer
+                     */
+                    if (null != folderPath) {
+                        buffer.add(session, folderID, Arrays.asList(folderPath));
+                    } else {
+                        buffer.add(session, folderID);
+                    }
+                    if (null != oldParentFolderID) {
+                        buffer.add(session, oldParentFolderID);
+                    }
+                    return null;
+                }
+            };
+            /*
+             * add event to buffer asynchronously if possible
+             */
             ThreadPoolService threadPoolService = DriveEventServiceLookup.getService(ThreadPoolService.class, false);
             if (null != threadPoolService) {
-                threadPoolService.submit(insertTask, CallerRunsBehavior.<Void>getInstance());
+                threadPoolService.submit(insertTask, CallerRunsBehavior.<Void> getInstance());
             } else {
                 insertTask.call();
             }
